@@ -107,20 +107,21 @@ class GeckoAsyncSpa(Observable):
     def _get_version_handler_func(self) -> GeckoVersionProtocolHandler:
         assert self._protocol is not None
         return GeckoVersionProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(), parms=self.sendparms
+            self._protocol.get_and_increment_sequence_counter(False),
+            parms=self.sendparms,
         )
 
     def _get_channel_handler_func(self) -> GeckoGetChannelProtocolHandler:
         assert self._protocol is not None
         return GeckoGetChannelProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(),
+            self._protocol.get_and_increment_sequence_counter(False),
             parms=self.sendparms,
         )
 
     def _get_config_file_handler_func(self) -> GeckoConfigFileProtocolHandler:
         assert self._protocol is not None
         return GeckoConfigFileProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(),
+            self._protocol.get_and_increment_sequence_counter(False),
             parms=self.sendparms,
         )
 
@@ -333,7 +334,7 @@ class GeckoAsyncSpa(Observable):
         if not await self.struct.get(
             self._protocol,
             lambda: GeckoStatusBlockProtocolHandler.full_request(
-                self._protocol.get_and_increment_sequence_counter(),
+                self._protocol.get_and_increment_sequence_counter(False),
                 parms=self.sendparms,
             ),
         ):
@@ -471,7 +472,7 @@ class GeckoAsyncSpa(Observable):
         assert self._protocol is not None
         assert self.log_class is not None
         return GeckoStatusBlockProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(),
+            self._protocol.get_and_increment_sequence_counter(False),
             self.log_class.begin,
             self.log_class.end,
             parms=self.sendparms,
@@ -515,7 +516,7 @@ class GeckoAsyncSpa(Observable):
 
         pack_command_handler = await self._protocol.get(
             lambda: GeckoPackCommandProtocolHandler.set_value(
-                self._protocol.get_and_increment_sequence_counter(),  # type: ignore
+                self._protocol.get_and_increment_sequence_counter(True),  # type: ignore
                 self.pack_type,
                 self.config_version,
                 self.log_version,
@@ -551,7 +552,7 @@ class GeckoAsyncSpa(Observable):
 
         pack_command_handler = await self._protocol.get(
             lambda: GeckoPackCommandProtocolHandler.keypress(
-                self._protocol.get_and_increment_sequence_counter(),  # type: ignore
+                self._protocol.get_and_increment_sequence_counter(True),  # type: ignore
                 self.pack_type,
                 keypad,
                 parms=self.sendparms,
@@ -569,7 +570,7 @@ class GeckoAsyncSpa(Observable):
     def _get_watercare_handler_func(self) -> GeckoWatercareProtocolHandler:
         assert self._protocol is not None
         return GeckoWatercareProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(),
+            self._protocol.get_and_increment_sequence_counter(False),
             parms=self.sendparms,
         )
 
@@ -609,7 +610,7 @@ class GeckoAsyncSpa(Observable):
         assert self._protocol is not None
         set_watercare_handler = await self._protocol.get(
             lambda: GeckoWatercareProtocolHandler.set(
-                self._protocol.get_and_increment_sequence_counter(),  # type: ignore
+                self._protocol.get_and_increment_sequence_counter(False),  # type: ignore
                 new_mode,
                 parms=self.sendparms,
             )
@@ -622,7 +623,7 @@ class GeckoAsyncSpa(Observable):
     def _get_reminders_handler_func(self) -> GeckoRemindersProtocolHandler:
         assert self._protocol is not None
         return GeckoRemindersProtocolHandler.request(
-            self._protocol.get_and_increment_sequence_counter(),
+            self._protocol.get_and_increment_sequence_counter(False),
             parms=self.sendparms,
         )
 
