@@ -4,6 +4,7 @@ import logging
 import struct
 
 from ...const import GeckoConstants
+from ...config import GeckoConfig
 from .packet import GeckoPacketProtocolHandler
 
 SFILE_VERB = b"SFILE"
@@ -17,8 +18,8 @@ class GeckoConfigFileProtocolHandler(GeckoPacketProtocolHandler):
     def request(seq, **kwargs):
         return GeckoConfigFileProtocolHandler(
             content=b"".join([SFILE_VERB, struct.pack(">B", seq)]),
-            timeout=2,
-            retry_count=10,
+            timeout=GeckoConfig.PROTOCOL_TIMEOUT_IN_SECONDS,
+            retry_count=GeckoConfig.PROTOCOL_RETRY_COUNT,
             on_retry_failed=GeckoPacketProtocolHandler._default_retry_failed_handler,
             **kwargs,
         )
